@@ -15,20 +15,20 @@ namespace Sass {
 
         Context&          ctx;
 
-        void fallback_impl(AST_Node* n) {}
+        void fallback_impl(AST_Node_Ptr n) {}
 
     public:
-      CommaSequence_Selector* remove_placeholders(CommaSequence_Selector*);
+      Selector_List_Ptr remove_placeholders(Selector_List_Ptr);
 
     public:
         Remove_Placeholders(Context&);
         ~Remove_Placeholders() { }
 
-        void operator()(Block*);
-        void operator()(Ruleset*);
-        void operator()(Media_Block*);
-        void operator()(Supports_Block*);
-        void operator()(Directive*);
+        void operator()(Block_Ptr);
+        void operator()(Ruleset_Ptr);
+        void operator()(Media_Block_Ptr);
+        void operator()(Supports_Block_Ptr);
+        void operator()(Directive_Ptr);
 
         template <typename U>
         void fallback(U x) { return fallback_impl(x); }
