@@ -128,7 +128,7 @@ namespace Sass {
   void SourceMap::prepend(const OutputBuffer& out)
   {
     Offset size(out.smap.current_position);
-    for (auto __mapping = out.smap.mappings.begin(); __mapping != out.smap.mappings.end(); ++__mapping) { Mapping mapping = *(__mapping);
+    for (Mapping mapping : out.smap.mappings) {
       if (mapping.generated_position.line > size.line) {
         throw(std::runtime_error("prepend sourcemap has illegal line"));
       }
@@ -152,7 +152,7 @@ namespace Sass {
   void SourceMap::prepend(const Offset& offset)
   {
     if (offset.line != 0 || offset.column != 0) {
-      for (auto __mapping = mappings.begin(); __mapping != mappings.end(); ++__mapping) { Mapping& mapping = *(__mapping);
+      for (Mapping& mapping : mappings) {
         // move stuff on the first old line
         if (mapping.generated_position.line == 0) {
           mapping.generated_position.column += offset.column;
